Class: SMEditor::Rails::Engine

Inherits:
Rails::Engine
  • Object
show all
Defined in:
lib/smeditor/rails/engine.rb

Overview

Self-contained Rails engine. The browser bundle and theme are packaged under app/assets, so consuming applications only need the Ruby gem.